/* $Id: xmpp-completion.h,v 1.3 2007/08/25 15:18:01 cdidier Exp $ */

#ifndef __XMPP_COMPLETION_H
#define __XMPP_COMPLETION_H

__BEGIN_DECLS
void xmpp_completion_init(void);
void xmpp_completion_deinit(void);
__END_DECLS

#endif
