/* $Id: loudmouth-tools.h,v 1.5 2008/08/15 00:25:21 cdidier Exp $ */

#ifndef __LOUDMOUTH_TOOLS_H
#define __LOUDMOUTH_TOOLS_H

__BEGIN_DECLS
LmMessageNode	*lm_find_node(LmMessageNode *, const char *,
		     const char *, const char *);
__END_DECLS

#endif
