/* $Id: xmpp-formats.h,v 1.1 2008/08/21 22:43:27 cdidier Exp $ */

#ifndef __XMPP_FORMATS_H
#define __XMPP_FORMATS_H

__BEGIN_DECLS
void xmpp_formats_init(void);
void xmpp_formats_deinit(void);
__END_DECLS

#endif
