/* $Id: fe-rosters.h,v 1.1 2008/08/15 00:25:21 cdidier Exp $ */

#ifndef __FE_ROSTERS_H
#define __FE__ROSTERS_H

__BEGIN_DECLS
void fe_rosters_init(void);
void fe_rosters_deinit(void);
__END_DECLS

#endif
