/* $Id: fe-stanzas.h,v 1.1 2008/08/15 00:25:21 cdidier Exp $ */

#ifndef __FE_STANZAS_H
#define __FE_STANZAS_H

__BEGIN_DECLS
void fe_stanzas_init(void);
void fe_stanzas_deinit(void);
__END_DECLS

#endif
