/* $Id: chatstates.h,v 1.1 2008/08/19 22:58:01 cdidier Exp $ */

#ifndef __CHATSTATES_H
#define __CHATSTATES_H

__BEGIN_DECLS
void chatstates_init(void);
void chatstates_deinit(void);
__END_DECLS

#endif
